"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SMTP = {
    /**
     * Used by `nodemailer.createTransport()`
     * https://nodemailer.com/smtp/
     */
    TRANSPORT: {
        host: 'smtp.ethereal.email',
        port: 587,
        auth: {
            user: 'abc@ethereal.email',
            pass: 'pass'
        }
    },
    /**
     * Merged into nodemailer's `transporter.sendMail()`
     * https://nodemailer.com/usage/#sending-mail
     */
    MAIL: {
        from: 'accownts@example.com'
    }
};
/**
 * Port the API will be hosted on
 */
exports.PORT = 12345;
/**
 * Is this a production environment?
 */
exports.PROD = false;
/**
 * Your application's name as you want it displayed to users
 */
exports.NAME = 'App';
/**
 * For Jest tests. Keep this as such so the TypeScript compiler is happy
 */
exports.TESTS = {
    STORAGE: {
        dir: ''
    }
};
/**
 * This is the shared HS256 key which will be used by Accownt to sign JSON Web
 *  Tokens which your app will then verify using the same key
 */
exports.JWT_KEY = 'some_secret_key1234';
/**
 * Your application's home page. Generally should not require authentication
 */
exports.APP_HOME_URL = 'https://example.com';
/**
 * Where your users will be redirected after login. `{{JWT}}` will be replaced
 *  with the actual JWT.
 */
exports.APP_LOGIN_URL = 'https://example.com/login?jwt={{JWT}}';
/**
 * Your reCAPTCHA key. Leave empty if you don't want reCAPTCHA verification
 */
exports.RECAPTCHA_KEY = '';
/**
 * Absolute path to accownt-web
 */
exports.WEB_DIRECTORY = '/path/to/accownt/web';
/**
 * How long until expiry of the main JWT that is saved to a cookie and passed
 *  to your application. Eg: `60 | "2 days" | "10h" | "7d"`. A numeric value is
 *  interpreted as a seconds count. If you use a string be sure you provide the
 *  time units (days, hours, etc).
 */
exports.JWT_EXPIRES_IN = '30d';
/**
 * The name of the cookie which the JWT will be saved to.
 */
exports.JWT_COOKIE_NAME = 'jwt';
/**
 * URL for Accownt's web client (where your users will access it)
 */
exports.ACCOWNT_WEB_URL = 'https://example.com/accownt';
/**
 * URL for Accownt's API (accownt-server)
 */
exports.ACCOWNT_API_URL = 'https://example.com/api/accownt';
/**
 * How long until expiry of a temporary JWT. Used in passwordless login and
 *  verification emails.
 */
exports.TEMP_JWT_EXPIRES_IN = '1h';
/**
 * Options for the user database (uses node-persist). All that's needed is `dir`
 * https://www.npmjs.com/package/node-persist#async-initoptions-callback
 */
exports.STORAGE = {
    dir: '/path/to/accownt/user/db'
};
//# sourceMappingURL=config.default.js.map