"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const clean_1 = require("lib/email/clean");
const to_id_1 = require("lib/email/to-id");
const storage = require("node-persist");
const sign_1 = require("lib/jwt/sign");
const bcrypt = require("bcryptjs");
const speakeasy_1 = require("speakeasy");
const { JWT_EXPIRES_IN, STORAGE } = process.enve;
async function login(email, pass, otp) {
    await storage.init(STORAGE);
    // Get user from email
    const userId = await to_id_1.emailToId(clean_1.cleanEmail(email));
    const user = await storage.getItem(`user-${userId}`);
    if (!user.password)
        throw 'You must request a passwordless login link';
    if (user.failedLogins >= 5 &&
        user.lastFailedLogin + 15 * 60 * 1000 > Date.now())
        throw 'Too many failed logins; wait 15 minutes';
    // Check password
    const match = await bcrypt.compare(pass, user.password);
    if (!match) {
        // Reset failedLogins after 15 minutes
        if (user.lastFailedLogin + 15 * 60 * 1000 < Date.now())
            user.failedLogins = 0;
        user.failedLogins++;
        user.lastFailedLogin = Date.now();
        await storage.setItem(`user-${userId}`, user);
        throw `Email/password do not match (${user.failedLogins} failed logins)`;
    }
    // Check OTP
    if (user.totpSecret && !speakeasy_1.totp.verify({ secret: user.totpSecret, token: otp }))
        throw 'Invalid one-time password (2FA code)';
    return sign_1.signJWT(userId, email, JWT_EXPIRES_IN);
}
exports.login = login;
//# sourceMappingURL=login.js.map