"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const build_template_1 = require("lib/email/build-template");
const to_id_1 = require("lib/email/to-id");
const send_1 = require("lib/email/send");
const storage = require("node-persist");
const sign_1 = require("lib/jwt/sign");
const { PASSWORDLESS_LOGIN_HTML_TEMPLATE, PASSWORDLESS_LOGIN_TEXT_TEMPLATE, TEMP_JWT_EXPIRES_IN, ACCOWNT_API_URL, STORAGE, NAME } = process.enve;
async function startPasswordlessLogin(email) {
    const userId = await to_id_1.emailToId(email);
    await storage.init(STORAGE);
    const user = await storage.getItem(`user-${userId}`);
    if (!user.verified)
        throw 'You must verify your account first';
    const token = await sign_1.signJWT(user.id, user.email, TEMP_JWT_EXPIRES_IN);
    const link = `${ACCOWNT_API_URL}/login/passwordless?jwt=${token}`;
    await send_1.sendMail({
        subject: `${NAME} Passwordless Login`,
        html: await build_template_1.buildTemplate({
            name: 'LINK',
            file: PASSWORDLESS_LOGIN_HTML_TEMPLATE,
            value: link,
            fallback: '<a href="%LINK%">Login.</a>'
        }),
        text: await build_template_1.buildTemplate({
            name: 'LINK',
            file: PASSWORDLESS_LOGIN_TEXT_TEMPLATE,
            value: link,
            fallback: 'Login: %LINK%"'
        }),
        to: user.email
    });
    return token;
}
exports.startPasswordlessLogin = startPasswordlessLogin;
//# sourceMappingURL=start.js.map