"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const build_template_1 = require("lib/email/build-template");
const set_password_1 = require("lib/account/set-password");
const check_email_1 = require("lib/register/check-email");
const clean_1 = require("lib/email/clean");
const send_1 = require("lib/email/send");
const storage = require("node-persist");
const sign_1 = require("lib/jwt/sign");
const qs = require("qs");
const axios_1 = require("axios");
const { EMAIL_VERIFICATION_HTML_TEMPLATE, EMAIL_VERIFICATION_TEXT_TEMPLATE, TEMP_JWT_EXPIRES_IN, ACCOWNT_API_URL, RECAPTCHA_KEY, STORAGE, NAME } = process.enve;
async function startRegistration(email, pass, recaptcha) {
    // Check if recaptcha response is valid
    if (RECAPTCHA_KEY) {
        const captcha = await axios_1.default.post('https://www.google.com/recaptcha/api/siteverify', qs.stringify({ secret: RECAPTCHA_KEY, response: recaptcha }));
        if (!captcha.data.success)
            throw 'Invalid captcha';
    }
    email = clean_1.cleanEmail(email);
    const { available } = await check_email_1.checkEmail(email);
    if (!available)
        throw 'Email is already taken';
    // Create user- and email- storage entries
    const user = {
        id: Date.now(),
        email,
        password: null,
        verified: false,
        totpSecret: null,
        failedLogins: 0,
        lastFailedLogin: 0
    };
    await storage.init(STORAGE);
    await storage.setItem(`user-${user.id}`, user);
    await storage.setItem(`email-${email}`, user.id);
    // Set password if needed
    if (pass)
        await set_password_1.setPassword(user.id, pass);
    // Send verification email
    const token = await sign_1.signJWT(user.id, email, TEMP_JWT_EXPIRES_IN);
    const link = `${ACCOWNT_API_URL}/register?jwt=${token}`;
    await send_1.sendMail({
        subject: `${NAME} Email Verification`,
        html: await build_template_1.buildTemplate({
            name: 'LINK',
            file: EMAIL_VERIFICATION_HTML_TEMPLATE,
            value: link,
            fallback: '<a href="%LINK%">Verify my email.</a>'
        }),
        text: await build_template_1.buildTemplate({
            name: 'LINK',
            file: EMAIL_VERIFICATION_TEXT_TEMPLATE,
            value: link,
            fallback: 'Verify your email: %LINK%"'
        }),
        to: email
    });
    return token;
}
exports.startRegistration = startRegistration;
//# sourceMappingURL=start.js.map